@@ -1,4 +1,4 @@
-### $Id: xport.R,v 1.1 1999/12/16 00:34:43 saikat Exp $
+### $Id: xport.R,v 1.3 2000/12/11 09:26:21 saikat Exp $
 ###
 ###             Read SAS xport format libraries
 ###
@@ -27,6 +27,8 @@ lookup.xport <- function(file) {
 
 read.xport <- function(file) {
   data.info <- lookup.xport(file)
-  lapply(.Call("xport_read", file, data.info, PACKAGE = "foreign"),
-         as.data.frame)
+  ans <- .Call("xport_read", file, data.info, PACKAGE = "foreign")
+  if (length(ans) == 1)
+    as.data.frame(ans[[1]])
+  else lapply(ans, as.data.frame)
 }
